@@ -6,6 +6,7 @@ from fastcodedog.context.contextbase import ContextBase
 from fastcodedog.context.model.column import Column
 from fastcodedog.context.model.computed_property import ComputedProperty
 from fastcodedog.context.model.additional_method import AdditionalMethod
+from fastcodedog.context.model.copy_method import CopyMethod
 from fastcodedog.context.model.relationship import Relationship
 
 
@@ -28,3 +29,5 @@ class Model(ContextBase):
         self._types['computed_properties'] = ComputedProperty
         self.additional_methods = {}
         self._types['additional_methods'] = AdditionalMethod
+        self.copy_methods = {}
+        self._types['copy_methods'] = CopyMethod
