@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from fastcodedog.context.api.oauth2 import OAuth2
 from fastcodedog.context.contextbase import ContextBase
 
 
@@ -24,5 +25,6 @@ class Config(ContextBase):
         super().__init__()
         self.database = Config.Database()
         self.logging = Config.Logging()
+        self.oauth2 = {'oauth2': {'expire_seconds': 7200}}
         self.user_configs = {}
         self._types['user_configs'] = dict
