@@ -31,6 +31,12 @@ if _all_configs_ is None:
         for option in config.options(section_):
             _all_configs_[section_][option] = config.get(section_, option)
 if section in _all_configs_ and key in _all_configs_[section]:
+    if default and isinstance(default, bool):
+        return _all_configs_[section][key].lower() == 'true'
+    elif default and isinstance(default, int):
+        return int(_all_configs_[section][key])
+    elif default and isinstance(default, float):
+        return float(_all_configs_[section][key])
     return _all_configs_[section][key]
 return default
 """, possible_imports=['configparser', 'os']))
@@ -55,10 +61,14 @@ return {{}}""", possible_imports=['configparser', 'os']))
         self.blocks.append(Variable('logging_config', value="get_configs('logging')"))
         self.blocks.append(Variable('port', value="get_config('app', 'port', 8000)"))
         self.blocks.append(Variable('db_url', value="get_config('database', 'url', None)"))
+        self.blocks.append(Variable('oauth2_expire_seconds', value="get_config('oauth2', 'expire_seconds', 7200)"))
 
         for key, sub_items in ctx_instance.config.user_configs.items():
             for k, v in sub_items.items():
-                self.blocks.append(Variable(f'{key}_{k}', value=f"get_config('{key}', '{k}')"))
+                if isinstance(v, str):
+                    self.blocks.append(Variable(f'{key}_{k}', value=f"get_config('{key}', '{k}', '{v}')"))
+                else:
+                    self.blocks.append(Variable(f'{key}_{k}', value=f"get_config('{key}', '{k}', {v})"))
 
     def save(self):
         super().save()
