@@ -56,7 +56,7 @@ class Main(File):
     LOGGING_CONFIG["loggers"]["uvicorn.access"]["propagate"] = True
     LOGGING_CONFIG["loggers"]["uvicorn"]["handlers"] = []
     LOGGING_CONFIG["loggers"]["uvicorn.access"]["handlers"] = []
-    uvicorn.run(app, host="0.0.0.0", port=int(port))""",
+    uvicorn.run(app, host="0.0.0.0", port=port)""",
                                 possible_imports=['uvicorn', Import('port', Config().package),
                                                   'from uvicorn.config import LOGGING_CONFIG']))
 
