@@ -13,8 +13,8 @@ from fastcodedog.util.inflect_wrapper import plural
 
 
 class Crud(Function):
-    POSSIBLE_IMPORTS = ['from datetime import datetime', 'from datetime import date', 'from datetime import time',
-                        'from sqlalchemy import exists', 'from sqlalchemy import select',
+    POSSIBLE_IMPORTS = ['import datetime', 'from datetime import datetime', 'from datetime import date', 'from datetime import time',
+                        'from sqlalchemy import exists', 'from sqlalchemy import select', 'from sqlalchemy import join',
                         'from sqlalchemy import or_', 'from sqlalchemy import and_']
 
     class Action(Enum):
@@ -51,6 +51,9 @@ class Crud(Function):
             for model in models.values():
                 if model.name == model_name:
                     return LocationFinder.get_package(model_name, 'model', model.module)
+        # 支持的系统模型
+        if model_name == 'datetime':
+            return None
         raise Exception(f'未找到模型：{model_name}')
 
 
@@ -86,6 +89,14 @@ class BaseCreate(Crud):
             if not column.nullable:
                 self.blocks.append(Text(f"if not {self.snake_name}.{column.name}:\n    {self.snake_name}.{column.name} = str(uuid.uuid4())",
                                         possible_imports='import uuid'))
+        # 添加默认值
+        for column, default_value in self.context.default_values.items():
+            if default_value.force_default:
+                self.blocks.append(Text(f"{self.snake_name}.{column} = {default_value.value_expression}"))
+            else:
+                self.blocks.append(Text(f"if '{column}' not in {self.snake_name}_create.dict(exclude_unset=True).keys():\n    {self.snake_name}.{column} = {default_value.value_expression}"))
+            if default_value.import_:
+                self.add_possible_imports(default_value.import_)
         self.blocks.append(Text(f"session.add({self.snake_name})"))
         self.blocks.append(Text(f"session.commit()"))
         self.blocks.append(Text(f"return {self.snake_name}"))
@@ -126,7 +137,16 @@ class BaseUpdate(Crud):
     continue"""
             self.blocks.append(Text(content, indent=self.DEFAULT_INDENT))
         self.blocks.append(Text(f"setattr({self.snake_name}, key, value)", indent=self.DEFAULT_INDENT))
-
+        # 添加默认值
+        for column, default_value in self.context.default_values.items():
+            if not default_value.change_when_update:
+                continue
+            if default_value.force_default:
+                self.blocks.append(Text(f"{self.snake_name}.{column} = {default_value.value_expression}"))
+            else:
+                self.blocks.append(Text(f"if '{column}' not in {self.snake_name}_update.dict(exclude_unset=True).keys():\n    {self.snake_name}.{column} = {default_value.value_expression}"))
+            if default_value.import_:
+                self.add_possible_imports(default_value.import_)
         self.blocks.append(Text(f"session.commit()"))
         self.blocks.append(Text(f"return {self.snake_name}"))
 
