@@ -12,6 +12,8 @@ class AdditionalMethod(Function):
             self.params[parameter.name] = Function.Parameter(name=parameter.name, type=parameter.type,
                                                              default_value=parameter.default_value,
                                                              nullable=parameter.nullable, comment=parameter.comment)
+            if parameter.comment:
+                self.comment += f'\n:param {parameter.name}: {parameter.comment}'
         self.blocks.append(Text(context.script, possible_imports=context.import_))
 
     # def serialize(self, delimiter='\n', with_comment=True):
