@@ -133,9 +133,17 @@ class Table:
         remote_side = None \
             if not (self.module == back_populates_module and self.get_model_name() == back_populates_model) \
             else referenced_key.code
-        foreign_keys = None \
-            if not (self.module == back_populates_module and self.get_model_name() == back_populates_model) \
-            else referenced_key.code
+        # foreign_keys = None \
+        #     if not (self.module == back_populates_module and self.get_model_name() == back_populates_model) \
+        #     else referenced_key.code
+        foreign_keys = None
+        if self.module == back_populates_module and self.get_model_name() == back_populates_model:
+            # 指向自己的外键关联
+            foreign_keys = referenced_key.code
+        # 如果有多个外键关联过来关联到同一个表，需要指定外键
+        if (not foreign_keys) and len([p_referenced_key for p_referenced_key in primary_key.referenced_keys
+                if p_referenced_key.table.code == referenced_key.table.code]) > 1:
+            foreign_keys = f'{back_populates_model}.{referenced_key.code}'
         return {'name': name, 'original_name': original_name, 'back_populates_module': back_populates_module,
                 'back_populates_model': back_populates_model,
                 'foreign_keys': foreign_keys, 'remote_side': remote_side, 'cascade': 'save-update, merge, delete',
